xd
==

A list of handy commands which makes life easier.


Install
-------

::

    pip install xd -U
    # pip install git+https://github.com/damnever/xd.git@master -U


Usage
-----

::

    xd --help
    xd <subcommand> --help
